/* 
 ---- SimpleMessageSystem Example 11 ----
 Control Wiring board functions with the following messages:
 
 r a -> read analog pins
 r d -> read digital pins
 r p -> read digital ports
 w d [pin] [value] -> write digital pin
 w p [port] [value] -> write digital port
 w a [pin] [value] -> write analog pin
 
 
 Base: Thomas Ouellet Fredericks 
 Additions: Alexandre Quessy 
 for Wiring: Sibylle Hauert
 */


void setup()
{
  
  // The following command initiates the serial port at 9600 baud. Please note this is VERY SLOW!!!!!! 
  // I suggest you use higher speeds in your own code. You can go up to 115200 with the USB version, that's 12x faster
  Serial.begin(9600); //Baud set at 9600 for compatibility, CHANGE!


}

void loop()
{

  if (messageBuild() > 0) { // Checks to see if the message is complete and erases any previous messages
    switch (messageGetChar()) { // Gets the first word as a character
    case 'r': // Read pins (analog or digital)
      readpins(); // Call the readpins function
      break; // Break from the switch
    case 'w': // Write pin or port
      writepin(); // Call the writepin function
    }

  }

}

void readpins(){ // Read pins (analog or digital)

  switch (messageGetChar()) { // Gets the next word as a character

    case 'd': // READ digital pins

    messageSendChar('d');  // Echo what is being read
    for (char i=8;i<16;i++) {
      messageSendInt(digitalRead(i)); // Read pins 8 to 15 --> as well possible read 0 to 39
    }
    messageEnd(); // Terminate the message being sent
    break; // Break from the switch
    
    case 'p': // READ digital ports

    messageSendChar('p');  // Echo what is being read
    for (char i=1;i<4;i++) {
      messageSendInt(portRead(i)); // Read digital ports 1, 2 and 3 --> as well possible read 0-4
    }
    messageEnd(); // Terminate the message being sent
    break; // Break from the switch
 
  case 'a': // READ analog pins

    messageSendChar('a');  // Echo what is being read
    for (char i=0;i<8;i++) {
      messageSendInt(analogRead(i)); // Read pins 0 to 7
    }
    messageEnd(); // Terminate the message being sent

  }

}

void writepin() { // Write pin

  int pin;
  int port;
  int state;

  switch (messageGetChar()) { // Gets the next word as a character

    case 'a' : // WRITE an analog pin

    pin = messageGetInt(); // Gets the next word as an integer
    state = messageGetInt(); // Gets the next word as an integer
    analogWrite(pin, state); //Sets the PWM of the pin 
    break;  // Break from the switch


    
    case 'd' : // WRITE a digital pin

    pin = messageGetInt();  // Gets the next word as an integer
    state = messageGetInt();  // Gets the next word as an integer
    pinMode(pin,OUTPUT);  //Sets the state of the pin to an output
    digitalWrite(pin,state);  //Sets the state of the pin HIGH (1) or LOW (0)
    
    
    case 'p' : // WRITE a digital port

    port = messageGetInt();  // Gets the next word as an integer
    state = messageGetInt();  // Gets the next word as an integer
    portMode(port,OUTPUT);  //Sets the state of the port to an output
    portWrite(port,state);  //Sets the state of the 8 pins of the port HIGH (1) or LOW (0)
  }

}

